@@ -8,9 +8,17 @@ use warnings;
 use Carp ();
 
 use overload
-    '${}' => sub { $_[0]->{scalar} },
+    '${}' => sub {
+	no overloading '%{}', '${}';
+	if ($_[0]->{overloads}{'${}'}) {
+	    Patro::LeumJelly::deref_handler(@_,'${}');
+	} else {
+	    $_[0]->{scalar}
+	}
+    },
     'nomethod' => \&Patro::LeumJelly::overload_handler,
-    '@{}' => \&Patro::LeumJelly::array_deref_handler,
+    '@{}' => sub { Patro::LeumJelly::deref_handler(@_,'@{}') },
+    '%{}' => sub { Patro::LeumJelly::deref_handler(@_,'%{}') },
     ;
 
 # override UNIVERSAL methods
@@ -24,6 +32,7 @@ foreach my $umethod (keys %UNIVERSAL::) {
 	    return &$umethod($proxy,@_);
 	}
 	my $context = defined(wantarray) ? 1 + wantarray : 0;
+	no overloading '%{}';
 	return Patro::LeumJelly::proxy_request( $proxy,
 	    { id => $proxy->{id}, topic => 'METHOD', command => $umethod,
 	      has_args => @_ > 0, args => [ @_ ], context => $context }, @_ );
@@ -39,6 +48,7 @@ sub AUTOLOAD {
     my $args = [ @_ ];
 
     my $context = defined(wantarray) ? 1 + wantarray : 0;
+    no overloading '%{}';
 
     return Patro::LeumJelly::proxy_request( $self, 
 	{ id => $self->{id},
@@ -52,6 +62,7 @@ sub AUTOLOAD {
 
 sub DESTROY {
     my $self = shift;
+    no overloading '%{}';
     return if $self->{_DESTROY}++;
     my $socket = $self->{socket};
     if ($socket) {
@@ -74,6 +85,7 @@ sub DESTROY {
 
 sub Patro::Tie::SCALAR::TIESCALAR {
     my ($pkg,$proxy) = @_;
+    no overloading '%{}';
     return bless { obj => $proxy, id => $proxy->{id} }, $pkg;
 }
 
